summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/messagebox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kalarm/lib/messagebox.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/messagebox.h')
-rw-r--r--kalarm/lib/messagebox.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kalarm/lib/messagebox.h b/kalarm/lib/messagebox.h
index 6d65b0934..21d321b13 100644
--- a/kalarm/lib/messagebox.h
+++ b/kalarm/lib/messagebox.h
@@ -58,7 +58,7 @@ class MessageBox : public KMessageBox
*/
static void setContinueDefault(const TQString& dontAskAgainName, ButtonCode defaultButton);
/** Displays a Continue/Cancel message box with the option as to which button is the default.
* @param parent Parent widget
* @param defaultButton The default button for the message box. Valid values are Continue or Cancel.
* @param text Message string
* @param caption Caption (window title) of the message box
@@ -66,12 +66,12 @@ class MessageBox : public KMessageBox
* @param dontAskAgainName If specified, the message box will only be suppressed
* if the user chose Continue last time.
*/
- static int warningContinueCancel(TQWidget* parent, ButtonCode defaultButton, const TQString& text,
- const TQString& caption = TQString::null,
+ static int warningContinueCancel(TQWidget* tqparent, ButtonCode defaultButton, const TQString& text,
+ const TQString& caption = TQString(),
const KGuiItem& buttonContinue = KStdGuiItem::cont(),
- const TQString& dontAskAgainName = TQString::null);
+ const TQString& dontAskAgainName = TQString());
/** Displays a Continue/Cancel message box.
* @param parent Parent widget
* @param text Message string
* @param caption Caption (window title) of the message box
* @param buttonContinue The text for the first button (default = i18n("Continue"))
@@ -81,9 +81,9 @@ class MessageBox : public KMessageBox
* @p dontAskAgainName value. If neither method has been used to set a default button,
* Continue is the default.
*/
- static int warningContinueCancel(TQWidget* parent, const TQString& text, const TQString& caption = TQString::null,
+ static int warningContinueCancel(TQWidget* tqparent, const TQString& text, const TQString& caption = TQString(),
const KGuiItem& buttonContinue = KStdGuiItem::cont(),
- const TQString& dontAskAgainName = TQString::null);
+ const TQString& dontAskAgainName = TQString());
/** If there is no current setting for whether a non-Yes/No message box should be
* shown, sets it to @p defaultShow.
* If a Continue/Cancel message box has Cancel as the default button, either
@@ -58,7 +58,7 @@ class MessageBox : public KMessageBox
static void setContinueDefault(const TQString& dontAskAgainName, ButtonCode defaultButton);
/** Displays a Continue/Cancel message box with the option as to which button is the default.
- * @param parent Parent widget
+ * @param tqparent Parent widget
* @param defaultButton The default button for the message box. Valid values are Continue or Cancel.
* @param text Message string
@@ -66,12 +66,12 @@ class MessageBox : public KMessageBox
/** Displays a Continue/Cancel message box.
- * @param parent Parent widget
+ * @param tqparent Parent widget
* @param text Message string
* @param caption Caption (window title) of the message box